SnakeBridge.InvalidRefError exception (SnakeBridge v0.13.0)
View SourceRaised when a ref payload is malformed or invalid.
This occurs when the ref structure is missing required fields or has an unrecognized format.
Fields
:reason- Why the ref is invalid (atom or string):message- Human-readable error message