SnakeBridge.RefNotFoundError exception (SnakeBridge v0.16.0)

Copy Markdown View Source

Raised when a Python object reference cannot be found in the registry.

This typically occurs when:

  • The ref was already released via release_ref/1
  • The session was released via release_session/1
  • The ref expired due to TTL
  • The ref was evicted due to registry size limits

Fields

  • :ref_id - The ref ID that was not found
  • :session_id - The session ID the ref was looked up in
  • :message - Human-readable error message

Summary

Types

t()

@type t() :: %SnakeBridge.RefNotFoundError{
  __exception__: true,
  message: String.t(),
  ref_id: String.t() | nil,
  session_id: String.t() | nil
}