SnakeBridge.Telemetry.ScriptShutdownForwarder (SnakeBridge v0.11.0)

Forwards Snakepit script shutdown telemetry events under the SnakeBridge namespace.

This module re-emits:

  • [:snakepit, :script, :shutdown, :start|:stop|:cleanup|:exit] as
  • [:snakebridge, :script, :shutdown, :start|:stop|:cleanup|:exit] with snakebridge_version metadata.

Summary

Functions

Attaches the shutdown forwarder to Snakepit script shutdown events.

Detaches the shutdown forwarder.

Functions

attach()

@spec attach() :: :ok | {:error, :already_exists}

Attaches the shutdown forwarder to Snakepit script shutdown events.

Returns :ok on success or {:error, :already_exists} if already attached.

detach()

@spec detach() :: :ok | {:error, :not_found}

Detaches the shutdown forwarder.