SnakeBridge.InvalidRefError exception (SnakeBridge v0.16.0)

Copy Markdown View Source

Raised when a ref payload is malformed or invalid.

This occurs when the ref structure is missing required fields or has an unrecognized format.

Fields

  • :reason - Why the ref is invalid (atom or string)
  • :message - Human-readable error message

Summary

Types

t()

@type t() :: %SnakeBridge.InvalidRefError{
  __exception__: true,
  message: String.t(),
  reason: atom() | String.t() | nil
}