Raised when a ref payload is malformed or invalid.
This occurs when the ref structure is missing required fields or has an unrecognized format.
:reason
:message
@type t() :: %SnakeBridge.InvalidRefError{ __exception__: true, message: String.t(), reason: atom() | String.t() | nil }